﻿using System.Data;
using System.Data.SqlClient;
using System.Windows;

namespace TestProject
{
    /// <summary>
    /// 메인 윈도우
    /// </summary>
    public partial class MainWindow : Window
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// SQL 데이터 어댑터
        /// </summary>
        private SqlDataAdapter sqlDataAdapter;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainWindow()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();

            InitializeSQLDataAdapter();

            this.gridControl.ItemsSource = GetData();
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 버튼 클릭시 처리하기 - button_Click(pSender, pRoutedEventArgs)

        /// <summary>
        /// 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="pSender">이벤트 발생자</param>
        /// <param name="pRoutedEventArgs">이벤트 인자</param>
        private void button_Click(object pSender, RoutedEventArgs pRoutedEventArgs)
        {
            this.gridControl.View.CommitEditing();

            this.sqlDataAdapter.Update((this.gridControl.ItemsSource as DataView).Table);
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////// Function

        #region SQL 데이터 어댑터 초기화 하기 - InitializeSQLDataAdapter()

        /// <summary>
        /// SQL 데이터 어댑터 초기화 하기
        /// </summary>
        private void InitializeSQLDataAdapter()
        {
            SqlConnection sqlConnection = new SqlConnection("Data Source=127.0.0.1;Initial Catalog=Northwind;Integrated Security=True");

            this.sqlDataAdapter = new SqlDataAdapter("SELECT [RegionID], [RegionDescription] FROM [Region]", sqlConnection);

            this.sqlDataAdapter.UpdateCommand = new SqlCommand("UPDATE Region SET RegionDescription = @RegionDescription WHERE RegionID = @RegionID", sqlConnection);

            this.sqlDataAdapter.UpdateCommand.Parameters.Add("@RegionID"         , SqlDbType.Int    ,  4, "RegionID"         );
            this.sqlDataAdapter.UpdateCommand.Parameters.Add("@RegionDescription", SqlDbType.VarChar, 50, "RegionDescription");
        }

        #endregion
        #region 데이터 구하기 - GetData()

        /// <summary>
        /// 데이터 구하기
        /// </summary>
        /// <returns>DataView 객체</returns>
        private DataView GetData()
        {
            DataSet dataSet = new DataSet();

            this.sqlDataAdapter.Fill(dataSet);

            return dataSet.Tables[0].DefaultView;
        }

        #endregion
    }
}